@@ -504,17 +504,12 @@ class Generator(metaclass=abc.ABCMeta):
                 for a in attributes if not (a[0].startswith('__') and a[0].endswith('__') or a[0].startswith('_'))
                 }
 
-    def get_cluster_info(self, generatedDataset=None):
+    @property
+    def cluster_info(self):
 
         """
         Returns clusters info.
 
-        Parameters
-        ----------
-
-        generatedDataset: Dataset object
-            Generated dataset (java object).
-
         Returns
         -------
 
@@ -525,7 +520,7 @@ class Generator(metaclass=abc.ABCMeta):
         --------
         >>> generator = BiclusterGenerator(silence=True)
         >>> generator.generate(no_return=True)
-        >>> generator.get_cluster_info()
+        >>> generator.cluster_info
         {'0': {'%Errors': '0', 'Type': 'Numeric', '%Missings': '0', '%Noise': '0', 'X': [15, 51, 63, 92],
         'Y': [7, 29, 35, 94], 'RowPattern': 'Constant', 'ColumnPattern': 'Constant',
         'Data': [['-8.61', '-8.61', '-8.61', '-8.61'], ['-8.61', '-8.61', '-8.61', '-8.61'],
@@ -534,30 +529,25 @@ class Generator(metaclass=abc.ABCMeta):
 
         """
 
-        if generatedDataset is None:
-            generatedDataset = self.generatedDataset
+        if self.generatedDataset is None:
+            return dict()
 
         cluster_type = {2: 'bi', 3: 'Tri'}[self._n]
-        geninfo_params = {2: [generatedDataset, False], 3: [generatedDataset]}[self._n]
+        geninfo_params = {2: [self.generatedDataset, False], 3: [self.generatedDataset]}[self._n]
 
         js = json.loads(
-            str(getattr(generatedDataset, 'get{}csInfoJSON'.format(cluster_type.capitalize()))
+            str(getattr(self.generatedDataset, 'get{}csInfoJSON'.format(cluster_type.capitalize()))
                 (*geninfo_params).getJSONObject('{}clusters'.format(cluster_type)).toString())
         )
 
         return js
 
-    def get_coverage(self, generatedDataset=None):
+    @property
+    def coverage(self):
 
         """
         Returns clusters dataset coverage.
 
-        Parameters
-        ----------
-
-        generatedDataset: Dataset object
-            Generated dataset (java object).
-
         Returns
         -------
 
@@ -568,15 +558,15 @@ class Generator(metaclass=abc.ABCMeta):
         --------
         >>> generator = BiclusterGenerator(silence=True)
         >>> generator.generate(no_return=True)
-        >>> generator.get_coverage()
+        >>> generator.coverage
         0.16
 
         """
+        if self.generatedDataset is None:
+            return float(0)
 
-        if generatedDataset is None:
-            generatedDataset = self.generatedDataset
-
-        return ((generatedDataset.getSize() - generatedDataset.getBackgroundSize()) / generatedDataset.getSize()) * 100
+        return ((self.generatedDataset.getSize() - self.generatedDataset.getBackgroundSize()) /
+                self.generatedDataset.getSize()) * 100
 
     @abc.abstractmethod
     def _initialize_seed(self):
@@ -799,7 +789,7 @@ class Generator(metaclass=abc.ABCMeta):
 
         # Get clusters
 
-        js = self.get_cluster_info()
+        js = self.cluster_info
 
         keys = keys[:self._n]
 
@@ -811,7 +801,7 @@ class Generator(metaclass=abc.ABCMeta):
 
     @staticmethod
     @abc.abstractmethod
-    def _dense_to_dgl(x, device, cuda=0):
+    def _dense_to_dgl(x, device, cuda=0, nclusters=1, clust_init='zeros'):
 
         """
         Extracts a partite dgl graph from a numpy array
@@ -859,7 +849,7 @@ class Generator(metaclass=abc.ABCMeta):
         """
         pass
 
-    def to_graph(self, x=None, framework='networkx', device='cpu', cuda=0):
+    def to_graph(self, x=None, framework='networkx', device='cpu', **kwargs):
 
         """
         Returns a n-partite graph, where n==dim.
@@ -873,8 +863,8 @@ class Generator(metaclass=abc.ABCMeta):
             Backend to use to build graph.
         device: {'cpu', 'gpu'}, default 'cpu'
             Type of device for storing the tensor. Only used if framework==dgl.
-        cuda: int, default 0
-            Index of cuda device to use. Only used if device==True and framework==dgl.
+        **kwargs: any, default None
+            Additional keywords that are passed on.
 
         Returns
         -------
@@ -938,7 +928,7 @@ class Generator(metaclass=abc.ABCMeta):
                               'DGL will be used instead.')
 
             # call private method
-            self.graph = getattr(self, '_dense_to_{}'.format(framework))(x, device=device, cuda=cuda)
+            self.graph = getattr(self, '_dense_to_{}'.format(framework))(x, device=device, **kwargs)
 
             return self.graph
 
