@@ -8,3 +8,7 @@ def tensor_value_check(value):
 
     except ValueError:
         return np.nan
+
+
+def loader(module, cls):
+    return getattr(module, cls) if isinstance(cls, str) else cls
