@@ -55,7 +55,6 @@ class TestCaseBase(unittest.TestCase):
             raise AssertionError("File exists: %s" % str(path))
 
 
-# TODO test getters
 class GenTest(TestCaseBase):
 
     def test_silence(self):
@@ -144,14 +143,14 @@ class GenTest(TestCaseBase):
         self.assertTrue(instance_N._asses_memory(gends=gends_T))
         self.assertFalse(instance_N._asses_memory(gends=gends_F))
 
-    def test_getters(self):
+    def test_properties(self):
 
         instance = bg(silence=True)
         instance.generate()
 
         self.assertTrue(isinstance(instance.get_params(), dict))
-        self.assertTrue(isinstance(instance.get_cluster_info(), dict))
-        self.assertTrue(isinstance(instance.get_coverage(), float))
+        self.assertTrue(isinstance(instance.cluster_info, dict))
+        self.assertTrue(isinstance(instance.coverage, float))
 
 
 class BicsGenTest(TestCaseBase):
